@@ -46,7 +46,7 @@
 (defconst subed-vtt--regexp-timestamp "\\(?:\\(?:[0-9]+\\):\\)?\\(?:[0-9]+\\):\\(?:[0-9]+\\)\\(?:\\.\\(?:[0-9]+\\)\\)?")
 (defconst subed-vtt--regexp-separator "\\(?:\\(?:[ \t]*\n\\)+\\(?:NOTE[ \t\n]*[ \t]*\n[ \t]*\n\\)?\\)"
   "Blank lines and possibly a comment.")
-(defconst subed-vtt--regexp-blank-separator "\\(?:[ \t]*\n[ \t]*\n\\|\\`\\(?:[ \t\n]*\\)\\)")
+(defconst subed-vtt--regexp-blank-separator "[ \t]*\n[ \t]*\n")
 (defconst subed-vtt--regexp-note "\\(NOTE[ \t\n]\\)")
 (defconst subed-vtt--regexp-identifier
   ;; According to https://developer.mozilla.org/en-US/docs/Web/API/WebVTT_API
@@ -394,6 +394,7 @@ Use the format-specific function for MAJOR-MODE."
 If COMMENT is nil or the empty string, remove the comment.
 If SUB-ID is not given, use the subtitle on point.
 Use the format-specific function for MAJOR-MODE."
+  (setq comment (and comment (string-trim comment)))
   (let ((comment-start (subed-jump-to-subtitle-comment sub-id)))
     ;; remove previous comment
     (if comment-start
